@@ -11,16 +11,11 @@ with 'WebService::Braintree::Role::MakeRequest';
 
 use WebService::Braintree::_::AddOn;
 
-use WebService::Braintree::Util qw(to_instance_array);
-
-has 'gateway' => (is => 'ro');
-
 sub all {
     my $self = shift;
-
-    my $response = $self->gateway->http->get("/add_ons");
-    my $attrs = $response->{add_ons} || [];
-    return to_instance_array($attrs, 'WebService::Braintree::_::AddOn');
+    return $self->_array_request(
+        '/add_ons', 'add_ons', 'WebService::Braintree::_::AddOn',
+    );
 }
 
 __PACKAGE__->meta->make_immutable;
